# DEPRECATED - lseg-analytics

**This package has been deprecated and is no longer maintained.**

Please use the new package lseg-analytics-pricing instead.

To use the new package, please uninstall this package: `pip uninstall lseg-analytics` and then install the new package: `pip install lseg-analytics-pricing`
